@@ -35,7 +35,7 @@ static AtkObject* html_view_accessible_get_focus_object    (GtkWidget          *
 
 static void       focus_object_destroyed                   (gpointer           data);       
 static void       set_focus_object                         (GObject            *obj,
-                                                            GObject            *focus_obj);       
+                                                            AtkObject          *focus_obj);       
 
 static gpointer parent_class = NULL;
 
@@ -124,9 +124,8 @@ html_view_accessible_initialize (AtkObject *obj,
 			  G_CALLBACK (html_view_accessible_grab_focus_cb),
                           NULL);
 	focus_object = html_view_accessible_get_focus_object (widget);
-	if (focus_object) {
-		set_focus_object (G_OBJECT (obj), G_OBJECT (focus_object));
-	}
+	if (focus_object)
+		set_focus_object (G_OBJECT (obj), focus_object);
 }
 
 static void
@@ -203,17 +202,14 @@ static void
 html_view_accessible_grab_focus_cb (GtkWidget *widget)
 {
 	AtkObject *focus_object;
+	AtkObject *obj;
 
 	focus_object = html_view_accessible_get_focus_object (widget);
-	if (focus_object) {
-		AtkObject *obj;
 
-		obj = gtk_widget_get_accessible (widget);
-		set_focus_object (G_OBJECT (obj), G_OBJECT (focus_object));
-		if (GTK_WIDGET_HAS_FOCUS (widget)) {
-			atk_focus_tracker_notify (focus_object);
-		}
-	}
+	obj = gtk_widget_get_accessible (widget);
+	set_focus_object (G_OBJECT (obj), focus_object);
+	if (GTK_WIDGET_HAS_FOCUS (widget) && focus_object)
+		atk_focus_tracker_notify (focus_object);
 }
 
 static AtkObject*
@@ -268,7 +264,7 @@ static void focus_object_destroyed (gpointer data)
 
 static void
 set_focus_object (GObject *obj,
-                  GObject *focus_obj) 
+                  AtkObject *focus_obj) 
 {
 	gpointer old_focus_obj;
 
@@ -278,8 +274,9 @@ set_focus_object (GObject *obj,
 				     (GWeakNotify) focus_object_destroyed,
 				     obj);
 	}
-	g_object_weak_ref (focus_obj, 
-			     (GWeakNotify) focus_object_destroyed,
-			     obj);
+	if (focus_obj)
+		g_object_weak_ref (G_OBJECT (focus_obj), 
+				   (GWeakNotify) focus_object_destroyed,
+				   obj);
 	g_object_set_data (obj, "gail-focus-object", focus_obj);
 }      
