@@ -9,39 +9,45 @@
 
 static HtmlStyle *default_style = NULL;
 
-static gint
-html_style_get_base_size ()
+static GtkStyle *
+html_style_get_gtk_style (void)
 {
-	gint base_size = 14;
-	PangoFontDescription *font_desc;
-	GtkSettings *settings;
-	gchar *font_name;
+  	GtkStyle *style;
+	style = gtk_rc_get_style_by_paths (gtk_settings_get_default(),
+                                           "GtkTextView",
+                                           "TextView",
+                                           HTML_TYPE_VIEW);
+	if (!style) {
+		style = gtk_rc_get_style_by_paths (gtk_settings_get_default(),
+                                                   "GtkHtml",
+                                                   "HtmlView",
+                                                   GTK_TYPE_TEXT_VIEW);
+		if (!style) {
+			style = gtk_style_new ();
+                }
+        }
+      
+        return style;
+}
 
-	settings = gtk_settings_get_default ();
-	g_object_get (G_OBJECT (settings), "gtk-font-name", &font_name, NULL);
-	font_desc = pango_font_description_from_string (font_name);
-        g_free (font_name);
-        
- 	if (font_desc) { 
-	    base_size = pango_font_description_get_size (font_desc) / PANGO_SCALE;
-            pango_font_description_free (font_desc);
-	}
-	
-	return base_size;
+static PangoFontDescription*
+html_style_get_default_font_desc ()
+{
+	GtkStyle *style;
+
+	style = html_style_get_gtk_style ();
+
+	return style->font_desc;
 }
 
 static HtmlColor*
 html_style_get_default_text_color ()
 {
-	GtkStyle *style = gtk_rc_get_style_by_paths (gtk_settings_get_default(),
-						     "GtkHtml",
-						     "HtmlView",
-						     HTML_TYPE_VIEW);
-	GdkColor text_color;
-	if (!style)
-	  {
-	    style = gtk_style_new ();
-	  }
+	GdkColor  text_color;
+        GtkStyle *style;
+
+        style = html_style_get_gtk_style ();
+
 	text_color = style->text[GTK_STATE_NORMAL];
 
 	return html_color_new_from_rgb (text_color.red,
@@ -189,6 +195,7 @@ html_default_style_new (void)
         GtkSettings *settings;
         PangoFontDescription *font_desc;
         const gchar *family;
+        gfloat size;
 
 	/* Set refcount to 1 so it never will be deallocated */
 	result->refcount = 1;
@@ -207,18 +214,11 @@ html_default_style_new (void)
 	
 	html_style_set_outline_width (result, HTML_BORDER_WIDTH_MEDIUM);
 
-        settings = gtk_settings_get_default ();
-        g_object_get (G_OBJECT (settings), "gtk-font-name", &font_name, NULL);
-        font_desc = pango_font_description_from_string (font_name);
-        g_free (font_name);
+	font_desc = html_style_get_default_font_desc ();
         
-	/* FIXME: This should probably not be here */
-        family = pango_font_description_get_family (font_desc);
+	family = pango_font_description_get_family (font_desc);
+	size = pango_font_description_get_size (font_desc) / (gfloat)PANGO_SCALE;
         
-        if (!family) {
-                family = "sans";
-        }
-
 	inherited->font_spec = 
                 html_font_specification_new ((gchar *) family, 
                                              HTML_FONT_STYLE_NORMAL, 
@@ -226,10 +226,8 @@ html_default_style_new (void)
                                              HTML_FONT_WEIGHT_NORMAL, 
                                              HTML_FONT_STRETCH_NORMAL,
                                              HTML_FONT_DECORATION_NONE, 
-                                             html_style_get_base_size ());
-
-        pango_font_description_free (font_desc);
-        
+                                             size);
+	
 	/* Set the default color to match the GTK+ theme */
 	html_style_set_color (result, html_style_get_default_text_color ());
 	
